@@ -203,7 +203,7 @@ IMainWindow::loginCompleted()
     mEvent.distinct_id = m_user;
     mEvent.distinct_id = mEvent.distinct_id.toLower ();
     mEvent.properties["os"] = Lib::ref().getOsDetails();
-    mEvent.properties["version"] = "0.4.1902";
+    mEvent.properties["version"] = "0.4.1909";
 
     do {
         if (ATTS_SUCCESS == task->status) {
@@ -593,7 +593,7 @@ IMainWindow::onGvTextTaskDone()
 
         m_mixPanel.addEvent(m_user, "SMS sent");
 
-        oInbox.refreshLatestNotrash ();
+        oInbox.refreshLatestNoTrash ();
     }
 }//IMainWindow::onGvTextTaskDone
 
