@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2014  Yuvraaj Kelkar
+Copyright (C) 2009-2015  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -67,6 +67,11 @@ myMessageOutput(QtMsgType type, const char *msg)
 {
     int level = -1;
     switch (type) {
+#if QT_VERSION >= QT_VERSION_CHECK(5,5,0)
+    case QtInfoMsg:
+        level = 4;
+        break;
+#endif
     case QtDebugMsg:
         level = 3;
         break;
