@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2014  Yuvraaj Kelkar
+Copyright (C) 2009-2015  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -247,8 +247,11 @@ MainWindow::init()
                 this,
                 SLOT(onSystrayActivated(QSystemTrayIcon::ActivationReason)));
 
-        m_systrayIcon->setIcon (m_appIcon);
+        m_systrayIcon->setIcon (QIcon(":/qgv.png"));
+        //TODO: Unfuck this. Qt 5.5 has fucked it.
+#ifdef Q_OS_WIN32
         m_systrayIcon->setContextMenu (d->ui->menu_File);
+#endif
         QTimer::singleShot (100, m_systrayIcon, SLOT(show()));
         //m_systrayIcon->show ();
     }
